import sys
import os
import logging
from selenium import webdriver
from selenium.webdriver.chrome.service import Service
from selenium.webdriver.common.by import By
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC
import time

# Get the current script directory
current_dir = os.path.dirname(os.path.abspath(__file__))

# Configure logging
log_path = os.path.join(current_dir, "python_script.log")
logging.basicConfig(
    filename=log_path,
    filemode='w',
    level=logging.INFO,
    format='%(asctime)s - %(levelname)s - %(message)s'
)

logging.info("Starting the Python script.")

# Check if the IMDb URL and output path are passed as parameters
if len(sys.argv) < 3:
    logging.error("IMDb URL or output path was not provided as a parameter.")
    sys.exit("IMDb URL or output path was not provided as a parameter.")

imdb_url = sys.argv[1]
output_path = sys.argv[2]
logging.info(f"Using IMDb URL: {imdb_url}")
logging.info(f"Output path: {output_path}")

# Path to chromedriver.exe
chrome_path = os.path.join(current_dir, "chromedriver.exe")

# Ensure the ChromeDriver exists
if not os.path.exists(chrome_path):
    logging.error(f"ChromeDriver not found at path: {chrome_path}")
    sys.exit(f"ChromeDriver not found at path: {chrome_path}")

# Set Chrome options
chrome_options = webdriver.ChromeOptions()
chrome_options.add_argument("--no-sandbox")
chrome_options.add_argument("--disable-dev-shm-usage")
chrome_options.add_argument("--disable-gpu")  # Disable GPU for headless mode stability
chrome_options.add_argument("--headless")  # Running Chrome in headless mode
chrome_options.add_argument("--user-agent=Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.124 Safari/537.36")

# Start chromedriver.exe
service = Service(chrome_path)
driver = webdriver.Chrome(service=service, options=chrome_options)
logging.info(f"ChromeDriver started from: {chrome_path}")

try:
    # Open the base URL to set the cookie
    driver.get("https://www.imdb.com")
    cookie = {'name': 'example_cookie', 'value': 'example_value', 'domain': 'imdb.com'}
    driver.add_cookie(cookie)

    # Navigate to the IMDb page
    driver.get(imdb_url)
    logging.info(f"Page {imdb_url} loaded successfully.")

    # Handle "Select Your Preferences" popup
    try:
        popup = WebDriverWait(driver, 10).until(
            EC.presence_of_element_located((By.XPATH, "//div[contains(@class, 'sc-kDvujY')]"))
        )
        logging.info("'Select Your Preferences' popup detected.")

        accept_button = WebDriverWait(driver, 10).until(
            EC.element_to_be_clickable((By.XPATH, "//button[@data-testid='accept-button']"))
        )
        accept_button.click()
        logging.info("Clicked on the 'Accept' button to close the popup.")
    except Exception as e:
        logging.info("No 'Select Your Preferences' popup appeared or an error occurred.")

    # Wait for the page to load
    time.sleep(5)

    # Click all "More" buttons
    def click_see_more_buttons():
        while True:
            buttons = driver.find_elements(By.XPATH, "//span[@class='ipc-btn__text']//span[contains(@class, 'ipc-see-more__text')]")
            if not buttons:
                break
            for button in buttons:
                try:
                    driver.execute_script("arguments[0].scrollIntoView(true);", button)  # Scroll to the button to ensure its visible
                    time.sleep(1)
                    button.click()
                    logging.info("Clicked a 'See More' button.")
                    time.sleep(1)  # Short delay to ensure the click is registered
                except Exception as e:
                    logging.warning(f"Error clicking a 'See More' button: {e}")

    # Click the "See More" buttons
    click_see_more_buttons()

    # Retrieve the full source HTML of the page after all "More" buttons are clicked
    html_source = driver.page_source

    # Save the HTML to a file
    with open(output_path, 'w', encoding='utf-8') as file:
        file.write(html_source)
    logging.info(f"HTML saved to file: {output_path}")

except Exception as e:
    logging.error(f"An error occurred: {e}")

finally:
    driver.quit()
    logging.info("Browser closed.")
